Coverage for pygeodesy/deprecated/datum.py: 100%

1

2# -*- coding: utf-8 -*-

3

4 u'''DEPRECATED on 2022.09.12, use module L{pygeodesy.datums} or L{pygeodesy.ellipsoids} instead.

5'''

6

7# XXX only the items previously public

8 from pygeodesy.constants import R_FM, R_KM, R_M, R_MA, R_MB, R_NM, R_SM, R_VM

9 from pygeodesy.datums import Datum, Datums, Transform, Transforms

10 from pygeodesy.ellipsoids import Ellipsoid, Ellipsoids, Curvature2Tuple

11 from pygeodesy.lazily import _ALL_DEPRECATED, _ALL_OTHER

12

13 __all__ = _ALL_DEPRECATED.deprecated_datum

14 __version__ = '24.12.31'

15

16 assert _ALL_OTHER(Curvature2Tuple, Datum, Ellipsoid, Transform) + tuple(_.name for _ in

17 (Datums, Ellipsoids, Transforms,

18 R_FM, R_KM, R_M, R_MA, R_MB, R_NM, R_SM, R_VM)) == __all__

19

20# **) MIT License

21#

22# Copyright (C) 2016-2026 -- mrJean1 at Gmail -- All Rights Reserved.

23#

24# Permission is hereby granted, free of charge, to any person obtaining a

25# copy of this software and associated documentation files (the "Software"),

26# to deal in the Software without restriction, including without limitation

27# the rights to use, copy, modify, merge, publish, distribute, sublicense,

28# and/or sell copies of the Software, and to permit persons to whom the

29# Software is furnished to do so, subject to the following conditions:

30#

31# The above copyright notice and this permission notice shall be included

32# in all copies or substantial portions of the Software.

33#

34# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS

35# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,

36# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL

37# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR

38# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,

39# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR

40# OTHER DEALINGS IN THE SOFTWARE.